//>>built
define("dojo/nls/pmbdojo_nl-nl",{"dijit/form/nls/validate":{invalidMessage:"De opgegeven waarde is ongeldig.",missingMessage:"Deze waarde is verplicht.",rangeMessage:"Deze waarde is niet toegestaan.",_localized:{}},"dojo/cldr/nls/number":{scientificFormat:"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]",infinity:"\u221e",superscriptingExponent:"\u00d7",list:";",percentSign:"%",minusSign:"-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000\u00a0bln'.'",
"currencySpacing-afterCurrency-insertBetween":"\u00a0",nan:"NaN",plusSign:"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]",currencyFormat:"\u00a4\u00a0#,##0.00;(\u00a4\u00a0#,##0.00)",perMille:"\u2030",group:".",percentFormat:"#,##0%","decimalFormat-long":"000 biljoen",decimalFormat:"#,##0.###",decimal:",","currencySpacing-beforeCurrency-insertBetween":"\u00a0",exponential:"E",_localized:{}},"dijit/form/nls/ComboBox":{previousMessage:"Eerdere opties",
nextMessage:"Meer opties",_localized:{}},"dijit/nls/loading":{loadingState:"Bezig met laden...",errorState:"Er is een fout opgetreden",_localized:{}},"dijit/nls/common":{buttonOk:"OK",buttonCancel:"Annuleren",buttonSave:"Opslaan",itemClose:"Sluiten",_localized:{}},"dijit/_editor/nls/commands":{bold:"Vet",copy:"Kopi\u00ebren",cut:"Knippen","delete":"Wissen",indent:"Inspringen",insertHorizontalRule:"Horizontale liniaal",insertOrderedList:"Genummerde lijst",insertUnorderedList:"Lijst met opsommingstekens",
italic:"Cursief",justifyCenter:"Centreren",justifyFull:"Uitvullen",justifyLeft:"Links uitlijnen",justifyRight:"Rechts uitlijnen",outdent:"Uitspringen",paste:"Plakken",redo:"Opnieuw",removeFormat:"Opmaak verwijderen",selectAll:"Alles selecteren",strikethrough:"Doorhalen",subscript:"Subscript",superscript:"Superscript",underline:"Onderstrepen",undo:"Ongedaan maken",unlink:"Link verwijderen",createLink:"Link maken",toggleDir:"Schrijfrichting wijzigen",insertImage:"Afbeelding invoegen",insertTable:"Tabel invoegen/bewerken",
toggleTableBorder:"Tabelkader wijzigen",deleteTable:"Tabel wissen",tableProp:"Tabeleigenschap",htmlToggle:"HTML-bron",foreColor:"Voorgrondkleur",hiliteColor:"Achtergrondkleur",plainFormatBlock:"Alineastijl",formatBlock:"Alineastijl",fontSize:"Lettergrootte",fontName:"Lettertype",tabIndent:"Inspringen",fullScreen:"Volledig scherm in-/uitschakelen",viewSource:"HTML-bron bekijken",print:"Afdrukken",newPage:"Nieuwe pagina",systemShortcut:'De actie "${0}" is alleen beschikbaar in uw browser via een sneltoetscombinatie. Gebruik ${1}.',
ctrlKey:"ctrl+${0}",appleKey:"\u2318${0}",_localized:{}},"dijit/_editor/nls/FontChoice":{1:"xx-klein",2:"x-klein",3:"klein",4:"gemiddeld",5:"groot",6:"x-groot",7:"xx-groot",fontSize:"Grootte",fontName:"Lettertype",formatBlock:"Opmaak",serif:"serif","sans-serif":"sans-serif",monospace:"monospace",cursive:"cursief",fantasy:"fantasy",noFormat:"Geen",p:"Alinea",h1:"Kop",h2:"Subkop",h3:"Sub-subkop",pre:"Vooraf opgemaakt",_localized:{}},"dojox/editor/plugins/nls/latinEntities":{iexcl:"omgekeerd uitroepteken",
cent:"dollarcent",pound:"pond",curren:"algemeen muntsymbool",yen:"yen\nyuan",brvbar:"sluisteken\ngebroken streepje",sect:"paragraaf",uml:"umlaut/trema",copy:"copyright (auteursrecht)",ordf:"aanduiding vrouwelijk rangtelwoord (Spaans)",laquo:"linker guillemet\ndubbele punthaak openen",not:"niet-teken",shy:"zacht afbreekstreepje",reg:"gedeponeerd handelsmerk",macr:"macron\nbovenlijn",deg:"graad",plusmn:"plusminus\nplus-of-min",sup2:"superscript 2\nkwadraat",sup3:"superscript 3\ntot de derde",acute:"accent aigu",
micro:"micro (mu)",para:"paragraaf (pilcrow)",middot:"vermenigvuldigingspunt\nmiddle dot",cedil:"cedille",sup1:"superscript 1",ordm:"aanduiding mannelijk rangtelwoord (Spaans)",raquo:"rechter guillemet\ndubbele punthaak sluiten",frac14:"1/4 (kwart)",frac12:"1/2 (half)",frac34:"3/4 (driekwart)",iquest:"omgekeerd vraagteken",Agrave:"hoofdletter A met accent grave",Aacute:"hoofdletter A met accent aigu",Acirc:"hoofdletter A met accent circonflexe",Atilde:"hoofdletter A met tilde",Auml:"hoofdletter A met trema",
Aring:"hoofdletter A met corona",AElig:"hoofletter AE-ligatuur",Ccedil:"hoofdletter C met cedille",Egrave:"hoofdletter E met accent grave",Eacute:"hoofdletter E met accent aigu",Ecirc:"hoofdletter E met accent circonflexe",Euml:"hoofdletter E met trema",Igrave:"hoofdletter I met accent grave",Iacute:"hoofdletter I met accent aigu",Icirc:"hoofdletter I met accent circonflexe",Iuml:"hoofdletter I met trema",ETH:"hoofdletter ETH-ligatuur",Ntilde:"hoofdletter N met tilde",Ograve:"hoofdletter O met accent grave",
Oacute:"hoofdletter O met accent aigu",Ocirc:"hoofdletter O met accent circonflexe",Otilde:"hoofdletter O met tilde",Ouml:"hoofdletter O met trema",times:"maal",Oslash:"hoofdletter O doorgestreept",Ugrave:"hoofdletter U met accent grave",Uacute:"hoofdletter U met accent aigu",Ucirc:"hoofdletter U met accent circonflexe",Uuml:"hoofdletter U met trema",Yacute:"hoofdletter Y met accent aigu",THORN:"hoofdletter THORN",szlig:"sz-ligatuur\nringel S",agrave:"kleine letter a met accent grave",aacute:"kleine letter a met accent aigu",
acirc:"kleine letter a met accent circonflexe",atilde:"kleine letter a met tilde",auml:"kleine letter a met trema",aring:"kleine letter a met corona",aelig:"kleine letter ae-ligatuur",ccedil:"kleine letter c met cedille",egrave:"kleine letter e met accent grave",eacute:"kleine letter e met accent aigu",ecirc:"kleine letter e met accent circonflexe",euml:"kleine letter e met trema",igrave:"kleine letter i met accent grave",iacute:"kleine letter i met accent aigu",icirc:"kleine letter i met accent circonflexe",
iuml:"kleine letter i met trema",eth:"kleine letter eth",ntilde:"kleine letter n met tilde",ograve:"kleine letter o met accent grave",oacute:"kleine letter o met accent aigu",ocirc:"kleine letter o met accent circonflexe",otilde:"kleine letter o met tilde",ouml:"kleine letter o met trema",divide:"deelteken",oslash:"kleine letter o doorgestreept",ugrave:"kleine letter u met accent grave",uacute:"kleine letter u met accent aigu",ucirc:"kleine letter u met accent circonflexe",uuml:"kleine letter u met trema",
yacute:"kleine letter y met accent aigu",thorn:"kleine letter thorn",yuml:"kleine letter y met trema",fnof:"cursieve f\nfunctie\ngulden",Alpha:"Griekse hoofdletter alpha",Beta:"Griekse hoofdletter b\u00e8ta",Gamma:"Griekse hoofdletter gamma",Delta:"Griekse hoofdletter delta",Epsilon:"Griekse hoofdletter epsilon",Zeta:"Griekse hoofdletter z\u00e8ta",Eta:"Griekse hoofdletter \u00e8ta",Theta:"Griekse hoofdletter th\u00e8ta",Iota:"Griekse hoofdletter iota",Kappa:"Griekse hoofdletter kappa",Lambda:"Griekse hoofdletter lambda",
Mu:"Griekse hoofdletter mu",Nu:"Griekse hoofdletter nu",Xi:"Griekse hoofdletter xi",Omicron:"Griekse hoofdletter omicron",Pi:"Griekse hoofdletter pi",Rho:"Griekse hoofdletter rho",Sigma:"Griekse hoofdletter sigma",Tau:"Griekse hoofdletter tau",Upsilon:"Griekse hoofdletter ypsilon",Phi:"Griekse hoofdletter phi",Chi:"Griekse hoofdletter chi",Psi:"Griekse hoofdletter psi",Omega:"Griekse hoofdletter omega",alpha:"Griekse kleine letter alpha",beta:"Griekse kleine letter b\u00e8ta",gamma:"Griekse kleine letter gamma",
delta:"Griekse kleine letter delta",epsilon:"Griekse kleine letter epsilon",zeta:"Griekse kleine letter z\u00e8ta",eta:"Griekse kleine letter \u00e8ta",theta:"Griekse kleine letter th\u00e8ta",iota:"Griekse kleine letter iota",kappa:"Griekse kleine letter kappa",lambda:"Griekse kleine letter lambda",mu:"Griekse kleine letter mu",nu:"Griekse kleine letter nu",xi:"Griekse kleine letter xi",omicron:"Griekse kleine letter omicron",pi:"Griekse kleine letter pi",rho:"Griekse kleine letter rho",sigmaf:"Griekse kleine letter sigma (einde woord)",
sigma:"Griekse kleine letter sigma",tau:"Griekse kleine letter tau",upsilon:"Griekse kleine letter ypsilon",phi:"Griekse kleine letter phi",chi:"Griekse kleine letter chi",psi:"Griekse kleine letter psi",omega:"Griekse kleine letter omega",thetasym:"Griekse kleine letter th\u00e8ta (2e vorm)",upsih:"Griekse letter ypsilon met haakje",piv:"Griekse letter pi (2e vorm)",bull:"opsommingsteken\naandachtspunt",hellip:"beletseltekenweglatingsteken",prime:"accent\nminuut\nvoet",Prime:"dubbel accent\nseconde\ninch",
oline:"hoge lijn\nbovenstreepje",frasl:"deelteken/schuine streep",weierp:"Gotische P",image:"Gotische I\nimaginair deel",real:"Gotische R\nre\u00ebel deel",trade:"handelsmerk",alefsym:"alef",larr:"pijl naar links",uarr:"pijl omhoog",rarr:"pijl naar rechts",darr:"pijl omlaag",harr:"pijl links/rechts",crarr:"pijl omlaag en naar links\nterugloopteken",lArr:"dubbele pijl naar links",uArr:"dubbele pijl omhoog",rArr:"dubbele pijl naar rechts",dArr:"dubbele pijl omlaag",hArr:"dubbele pijl links/rechts",
forall:"voor alle geldt",part:"parti\u00eble differentiaal",exist:"er bestaat",empty:"lege verzameling\nnulverzameling\ndiameter",nabla:"nabla\ngradi\u00ebnt",isin:"is element van",notin:"is geen element van",ni:"heeft als element",prod:"product\nherhaald vermenigvuldigen",sum:"som\nherhaald optellen",minus:"min",lowast:"asterisk operator",radic:"wortel\nvierkantswortel",prop:"evenredig met",infin:"oneindig",ang:"hoek",and:"logische en",or:"logische of",cap:"snijpunt",cup:"vereniging","int":"integraal",
there4:"hieruit volgt",sim:"tilde operator\nvarieert met\nvergelijkbaar met",cong:"congruent aan",asymp:"ongeveer gelijk aan",ne:"niet gelijk aan",equiv:"identiek met",le:"kleiner dan of gelijk aan",ge:"groter dan of gelijk aan",sub:"is deelverzameling van",sup:"bevat deelverzameling",nsub:"is geen deelverzameling van",sube:"is deelverzameling van of is gelijk aan",supe:"bevat deelverzameling of is gelijk aan",oplus:"plus in cirkel\ndirecte som",otimes:"maal in cirkel\nvectorproduct",perp:"loodrecht\northogonaal met",
sdot:"punt operator",lceil:"linker afrondingshaakje (naar boven)",rceil:"rechter afrondingshaakje (naar boven)",lfloor:"linker afrondingshaakje (naar beneden)",rfloor:"linker afrondingshaakje (naar beneden)",lang:"punthaak openen",rang:"punthaak sluiten",loz:"ruit",spades:"schoppen",clubs:"klaveren",hearts:"harten",diams:"ruiten",OElig:"hoofdletter OE-ligatuur",oelig:"kleine letter oe-ligatuur",Scaron:"hoofdletter S met caron",scaron:"kleine letter s met caron",Yuml:"hoofdletter Y met trema",circ:"accent circonflexe",
tilde:"kleine tilde",ensp:"smalle spatie",emsp:"brede spatie",thinsp:"extra smalle spatie",zwnj:"verdelingsteken met breedte nul",zwj:"verbindingsteken met breedte nul",lrm:"van links naar rechts-markering",rlm:"van rechts naar links-markering",ndash:"divisie (kort steepje)",mdash:"divisie (lang steepje)",lsquo:"linker enkel aanhalingsteken",rsquo:"rechter enkel aanhalingsteken",sbquo:"apostrof (vorm \x3d 9)",ldquo:"linker dubbele aanhalingsteken",rdquo:"rechter dubbele aanhalingsteken",bdquo:"dubbele apostrof (vorm \x3d 9)",
dagger:"obelisk",Dagger:"dubbele obelisk",permil:"promille",lsaquo:"enkele linkswijzend aanhalingsteken",rsaquo:"enkele rechtswijzend aanhalingsteken",euro:"euro",_localized:{}},"dojox/editor/plugins/nls/InsertEntity":{insertEntity:"Symbool invoegen",_localized:{}},"dojo/nls/colors":{aliceblue:"lichtblauw",antiquewhite:"antiekwit",aqua:"aqua",aquamarine:"aquamarijn",azure:"azuur",beige:"beige",bisque:"oranjegeel",black:"zwart",blanchedalmond:"amandel",blue:"blauw",blueviolet:"violet",brown:"bruin",
burlywood:"lichtbruin",cadetblue:"donkerstaalblauw",chartreuse:"groengeel",chocolate:"chocoladebruin",coral:"koraalrood",cornflowerblue:"korenbloemblauw",cornsilk:"ma\u00efsgeel",crimson:"karmozijnrood",cyan:"cyaan",darkblue:"donkerblauw",darkcyan:"donkercyaan",darkgoldenrod:"donkergoud",darkgray:"donkergrijs",darkgreen:"donkergroen",darkgrey:"donkergrijs",darkkhaki:"donkerkaki",darkmagenta:"donkermagenta",darkolivegreen:"donkerolijfgroen",darkorange:"donkeroranje",darkorchid:"donkerorchidee",darkred:"donkerrood",
darksalmon:"donkerzalm",darkseagreen:"donkerzeegroen",darkslateblue:"donkergrijsblauw",darkslategray:"donkerblauwgrijs",darkslategrey:"donkerblauwgrijs",darkturquoise:"donkerturquoise",darkviolet:"donkerviolet",deeppink:"donkerroze",deepskyblue:"diephemelblauw",dimgray:"dofgrijs",dimgrey:"dofgrijs",dodgerblue:"helderblauw",firebrick:"vuursteenrood",floralwhite:"rozewit",forestgreen:"bosgroen",fuchsia:"fuchsia",gainsboro:"lichtblauwgrijs",ghostwhite:"spierwit",gold:"goud",goldenrod:"goudbruin",gray:"grijs",
green:"groen",greenyellow:"groengeel",grey:"grijs",honeydew:"meloen",hotpink:"acaciaroze",indianred:"indisch rood",indigo:"indigo",ivory:"ivoorwit",khaki:"kaki",lavender:"lavendelblauw",lavenderblush:"lavendelblos",lawngreen:"grasgroen",lemonchiffon:"citroengeel",lightblue:"lichtblauw",lightcoral:"lichtkoraal",lightcyan:"lichtcyaan",lightgoldenrodyellow:"lichtgoudgeel",lightgray:"lichtgrijs",lightgreen:"lichtgroen",lightgrey:"lichtgrijs",lightpink:"lichtroze",lightsalmon:"lichtzalm",lightseagreen:"lichtzeegroen",
lightskyblue:"lichthemelsblauw",lightslategray:"lichtblauwgrijs",lightslategrey:"lichtblauwgrijs",lightsteelblue:"lichtstaalblauw",lightyellow:"lichtgeel",lime:"limoen",limegreen:"limoengroen",linen:"linnen",magenta:"magenta",maroon:"kastanjebruin",mediumaquamarine:"midaquamarijn",mediumblue:"midblauw",mediumorchid:"midorchidee",mediumpurple:"midpurper",mediumseagreen:"midzeegroen",mediumslateblue:"midgrijsblauw",mediumspringgreen:"midlentegroen",mediumturquoise:"midturquoise",mediumvioletred:"midvioletrood",
midnightblue:"nachtblauw",mintcream:"mintroomgeel",mistyrose:"matroze",moccasin:"moccasin",navajowhite:"navajowit",navy:"marineblauw",oldlace:"kant",olive:"olijfgroen",olivedrab:"grijsbruin",orange:"oranje",orangered:"oranjerood",orchid:"orchidee",palegoldenrod:"bleekgeel",palegreen:"bleekgroen",paleturquoise:"bleekturquoise",palevioletred:"bleekvioletrood",papayawhip:"papajaroze",peachpuff:"perzikroze",peru:"bruin",pink:"roze",plum:"pruim",powderblue:"lichtblauw-wit",purple:"purper",red:"rood",rosybrown:"roodbruin",
royalblue:"koningsblauw",saddlebrown:"leerbruin",salmon:"zalm",sandybrown:"zandbruin",seagreen:"zeegroen",seashell:"schelp",sienna:"sienna",silver:"zilvergrijs",skyblue:"hemelsblauw",slateblue:"leiblauw",slategray:"leigrijs",slategrey:"leigrijs",snow:"sneeuwwit",springgreen:"lentegroen",steelblue:"staalblauw",tan:"geelbruin",teal:"grijsblauw",thistle:"distel",tomato:"tomaat",transparent:"transparant",turquoise:"turquoise",violet:"violet",wheat:"tarwebruin",white:"wit",whitesmoke:"rookwit",yellow:"geel",
yellowgreen:"geelgroen",_localized:{}},"dojox/widget/nls/ColorPicker":{redLabel:"r",greenLabel:"g",blueLabel:"b",hueLabel:"t",saturationLabel:"i",valueLabel:"h",degLabel:"\u00b0",hexLabel:"hex",huePickerTitle:"Tint selecteren",saturationPickerTitle:"Intensiteit selecteren",_localized:{}},"dojox/editor/plugins/nls/TableDialog":{insertTableTitle:"Tabel invoegen",modifyTableTitle:"Tabel wijzigen",rows:"Rijen",columns:"Kolommen",align:"Uitlijnen",cellPadding:"Celopvulling:",cellSpacing:"Celspati\u00ebring:",
tableWidth:"Tabelbreedte:",backgroundColor:"Achtergrondkleur:",borderColor:"Randkleur",borderThickness:"Randdikte:",percent:"percent",pixels:"pixels","default":"standaard",left:"links",center:"gecentreerd",right:"rechts",buttonSet:"Instellen",buttonInsert:"invoegen",buttonCancel:"Annuleren",selectTableLabel:"Tabel selecteren",insertTableRowBeforeLabel:"Rij boven toevoegen",insertTableRowAfterLabel:"Rij onder toevoegen",insertTableColumnBeforeLabel:"Kolom voor toevoegen",insertTableColumnAfterLabel:"Kolom achter toevoegen",
deleteTableRowLabel:"Rij wissen",deleteTableColumnLabel:"Kolom wissen",colorTableCellTitle:"Achtergrondkleur van tabelcel",tableContextMenuTitle:"Contextmenu voor tabel",_localized:{}},"dojox/editor/plugins/nls/PasteFromWord":{pasteFromWord:"Plakken vanuit Word",instructions:"Plak de content vanuit Word in het tekstvak hieronder. Klik als u klaar bent op de knop Plakken. Kies Annuleren als u de invoeging van tekst wilt afbreken.",_localized:{}},"dojox/editor/plugins/nls/InsertAnchor":{insertAnchor:"Anker invoegen",
title:"Ankereigenschappen",anchor:"Naam:",text:"Beschrijving:",set:"Instellen",cancel:"Annuleren",_localized:{}},"dojox/editor/plugins/nls/Blockquote":{blockquote:"Blockquote",_localized:{}},"dojox/editor/plugins/nls/LocalImage":{insertImageTitle:"Afbeelding invoegen",url:"Afbeelding",browse:"Bladeren...",text:"Beschrijving",set:"Invoegen",invalidMessage:"Ongeldig bestandstype voor afbeelding",prePopuTextUrl:"Geef een afbeeldings-URL op",prePopuTextBrowse:" of navigeer naar een lokaal bestand.",_localized:{}}});
//# sourceMappingURL=pmbdojo_nl-nl.js.map